# kkpyutil
Personal utility functions and classes frequently used by myself for daily Python work.

It does not necessarily benefit everybody, but I hope it 
may occasionally shed light on some issues you may have in your own work.

## INSTALL

```shell
pip3 install kkpyutil
```
